
# THIS FILE IS GENERATED FROM pyedflib SETUP.PY
short_version = '0.1.29'
version = '0.1.29'
full_version = '0.1.29'
git_revision = '902e956d1adaf20e1c5c149eb1531715f173d874'
release = True

if not release:
    version = full_version
